@@ -52,6 +52,7 @@ class ONNXRTAdaptor(Adaptor):
         self.static = framework_specific_info["approach"] == "post_training_static_quant"
         self.backend = framework_specific_info["backend"]
         self.work_space = framework_specific_info["workspace_path"]
+        self.graph_optimization = framework_specific_info["graph_optimization"]
         self.benchmark = (GLOBAL_STATE.STATE == MODE.BENCHMARK)
         os.makedirs(self.work_space, exist_ok=True)
         self.pre_optimized_model = None
@@ -152,6 +153,7 @@ class ONNXRTAdaptor(Adaptor):
         fwk_info['approach'] = self.static
         fwk_info['backend'] = self.backend
         fwk_info['workspace_path'] = self.work_space
+        fwk_info['graph_optimization'] = self.graph_optimization
         tune_cfg['framework_specific_info'] = fwk_info
         return tune_cfg
 
@@ -252,8 +254,7 @@ class ONNXRTAdaptor(Adaptor):
                 else:
                     origin_op_type = possible_int8_res[0].split('Integer')[0]
 
-                if node.op_type == "Pad" or node.op_type == "Split" \
-                        or node.op_type == "Gather":
+                if node.op_type in ["Pad", "Split", "Gather", "Concat", "Reshape"]:
                     if any([output.endswith('_quantized') for output in node.output]):
                         origin_op_type = node.op_type
                     else:
@@ -373,12 +374,23 @@ class ONNXRTAdaptor(Adaptor):
         model = split_shared_input(model)
         sess_options = ort.SessionOptions()
         level = self.query_handler.get_graph_optimization() # pylint: disable=no-member
+        if self.graph_optimization.level:
+            optimization_levels = {
+                    'DISABLE_ALL': ort.GraphOptimizationLevel.ORT_DISABLE_ALL,
+                    'ENABLE_BASIC': ort.GraphOptimizationLevel.ORT_ENABLE_BASIC,
+                    'ENABLE_EXTENDED': ort.GraphOptimizationLevel.ORT_ENABLE_EXTENDED,
+                    'ENABLE_ALL': ort.GraphOptimizationLevel.ORT_ENABLE_ALL}
+            assert self.graph_optimization.level in optimization_levels, "the optimization \
+                                      choices are {}".format(optimization_levels.keys())
+ 
+            level = optimization_levels[self.graph_optimization.level]
         sess_options.graph_optimization_level = level
         sess_options.optimized_model_filepath = os.path.join(self.work_space, \
             "Optimized_model.onnx")
         _ = ort.InferenceSession(model.model.SerializeToString(), sess_options)
         tmp_model = onnx.load(sess_options.optimized_model_filepath)
-        model.model = self._replace_gemm_with_matmul(tmp_model).model
+        model.model = self._replace_gemm_with_matmul(tmp_model).model \
+            if self.graph_optimization.gemm2matmul else tmp_model
         model.model = self._rename_node(model.model)
         self.pre_optimized_model = model
 
@@ -775,6 +787,7 @@ class ONNXRTQuery(QueryBackendCapability):
                                'ENABLE_BASIC': ort.GraphOptimizationLevel.ORT_ENABLE_BASIC,
                                'ENABLE_EXTENDED': ort.GraphOptimizationLevel.ORT_ENABLE_EXTENDED,
                                'ENABLE_ALL': ort.GraphOptimizationLevel.ORT_ENABLE_ALL}
+ 
         level = self.cur_config['graph_optimization']['level']
         assert level in optimization_levels, "the optimization choices \
                                               are {}".format(optimization_levels.keys())
