@@ -29,6 +29,7 @@ from ..objective import OBJECTIVES
 from ..utils.utility import fault_tolerant_file, equal_dicts, GLOBAL_STATE, MODE
 from ..utils.create_obj_from_config import create_eval_func, create_train_func
 from ..utils import logger
+from ..utils import OPTIONS
 from ..version import __version__
 from ..conf.dotdict import DotDict, deep_get, deep_set
 from ..algorithm import AlgorithmScheduler
@@ -150,6 +151,8 @@ class TuneStrategy(object):
             framework_specific_info.update({"backend": framework.lower().split('_')[-1]})
             framework_specific_info.update({"deploy_path": os.path.dirname(self.deploy_path)})
             framework_specific_info.update({'workspace_path': self.cfg.tuning.workspace.path})
+            framework_specific_info.update(
+                                {'graph_optimization': OPTIONS[framework].graph_optimization})
         if framework == 'pytorch_ipex' or framework == 'pytorch' or framework == 'pytorch_fx':
             framework_specific_info.update({"q_dataloader": q_dataloader})
             framework_specific_info.update(
@@ -309,10 +312,9 @@ class TuneStrategy(object):
             self.baseline = self._evaluate(self.model)
             # record the FP32 baseline
             self._add_tuning_history()
-        baseline_msg = '[accuracy: {:.4f}, {}: {:.4f}]'.format(self.baseline[0],
-                                                                str(self.objective.measurer),
-                                                                self.baseline[1]) \
-                                                                if self.baseline else 'n/a'
+        baseline_msg = '[Accuracy: {:.4f}, {}: {:.4f}]'.format(self.baseline[0],
+                                str(self.objective.measurer).capitalize(), \
+                                self.baseline[1]) if self.baseline else 'n/a'
         logger.info("FP32 baseline is: {}".format(baseline_msg))
 
         trials_count = 0
@@ -412,6 +414,10 @@ class TuneStrategy(object):
 
         return result
 
+    @property
+    def evaluation_result(self):
+        return self._evaluate(self.model)
+
     def _evaluate(self, model):
         """The interface of evaluating model.
 
@@ -444,7 +450,6 @@ class TuneStrategy(object):
                                          self.cfg.evaluation.accuracy.iteration, \
                                          tensorboard = self.cfg.tuning.tensorboard, \
                                          fp32_baseline = self.baseline == None)
-
             val = self.objective.evaluate(eval_func, model)
         assert np.isscalar(val[0]), \
             "The eval_func should return a scalar, but not {}!".format(str(type(val[0])))
@@ -484,14 +489,14 @@ class TuneStrategy(object):
         else:
             del self.last_qmodel
 
-        last_tune_msg = '[accuracy: {:.4f}, {}: {:.4f}]'.format(self.last_tune_result[0],
-                                                                str(self.objective.measurer),
-                                                                self.last_tune_result[1]) \
-                                                                if self.last_tune_result else 'n/a'
-        best_tune_msg = '[accuracy: {:.4f}, {}: {:.4f}]'.format(self.best_tune_result[0],
-                                                                str(self.objective.measurer),
-                                                                self.best_tune_result[1]) \
-                                                                if self.best_tune_result else 'n/a'
+        last_tune_msg = '[Accuracy (int8|fp32): {:.4f}|{:.4f}, {} (int8|fp32): {:.4f}|{:.4f}]'.format( \
+                                self.last_tune_result[0], self.baseline[0], \
+                                str(self.objective.measurer).capitalize(), \
+                                self.last_tune_result[1], self.baseline[1]) \
+                                if self.last_tune_result else 'n/a'
+        best_tune_msg = '[Accuracy: {:.4f}, {}: {:.4f}]'.format(self.best_tune_result[0], \
+                                str(self.objective.measurer).capitalize(), \
+                                self.best_tune_result[1]) if self.best_tune_result else 'n/a'
         logger.info("Tune {} result is: {}, Best tune result is: {}".format(trials_count,
                                                                             last_tune_msg,
                                                                             best_tune_msg))
