@@ -14,6 +14,8 @@ from neural_compressor.adaptor import FRAMEWORKS
 from neural_compressor.data import DATASETS, DATALOADERS
 from neural_compressor.experimental import Quantization, common
 from neural_compressor.experimental import Benchmark, common
+from neural_compressor import options
+from neural_compressor.adaptor.pytorch import get_torch_version, PyTorchVersionMode
 
 def build_static_yaml():
     fake_yaml = """
@@ -196,12 +198,6 @@ def build_non_MSE_yaml():
 def eval_func(model):
     return 1.0
 
-def get_torch_version():
-    try:
-        torch_version = torch.__version__.split('+')[0]
-    except ValueError as e:
-        assert False, 'Got an unknow version of torch: {}'.format(e)
-    return torch_version
 
 def export_onnx_model(model, path, opset=12):
     x = torch.randn(100, 3, 224, 224, requires_grad=True)
@@ -367,6 +363,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
                                "random_seed": 1234,
                                "q_dataloader": None,
                                "backend": "qlinearops",
+                               "graph_optimization": options.onnxrt.graph_optimization,
                                "workspace_path": './nc_workspace/{}/{}/'.format(
                                                        'onnxrt',
                                                        'imagenet')}
@@ -382,6 +379,8 @@ class TestAdaptorONNXRT(unittest.TestCase):
         adaptor.inspect_tensor(self.rn50_model, self.cv_dataloader, op_list.keys(), inspect_type='activation')
 
     def test_set_tensor(self):
+        options.onnxrt.graph_optimization.level = 'ENABLE_EXTENDED'
+        options.onnxrt.graph_optimization.gemm2matmul = False
         quantizer = Quantization("static.yaml")
         quantizer.calib_dataloader = self.cv_dataloader
         quantizer.eval_dataloader = self.cv_dataloader
@@ -392,6 +391,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
                      "random_seed": 1234,
                      "q_dataloader": None,
                      "backend": "qlinearops",
+                     "graph_optimization": options.onnxrt.graph_optimization,
                      "workspace_path": './nc_workspace/{}/{}/'.format(
                                              'onnxrt',
                                              'imagenet')}
@@ -401,7 +401,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
         adaptor.quantize_config = q_config
         version = get_torch_version()
         q_model.save('./best_model.onnx')
-        if version >= '1.7':
+        if version >= PyTorchVersionMode.PT17.value:
             adaptor.set_tensor(onnx.load("best_model.onnx"), 
                 {self.mb_v2_model.graph.node[0].input[1]: np.random.random([32, 3, 3, 3])})
             adaptor.set_tensor(q_model,
@@ -445,6 +445,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
                      "random_seed": 1234,
                      "q_dataloader": None,
                      "backend": "qlinearops",
+                     "graph_optimization": options.onnxrt.graph_optimization,
                      "workspace_path": './nc_workspace/{}/{}/'.format(
                                              'onnxrt',
                                              'imagenet')}
@@ -476,6 +477,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
             quantizer.model = common.Model(self.matmul_model)
             q_model = quantizer()
 
+        options.onnxrt.graph_optimization.level = 'ENABLE_BASIC'
         for fake_yaml in ["non_MSE.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.calib_dataloader = self.cv_dataloader
