@@ -94,6 +94,77 @@ class TestConvBiasAddAddReluFusion(unittest.TestCase):
 
             self.assertEqual(found_conv_fusion, False)
 
+    @disable_random()
+    def test_depthwiseconv_biasadd_fusion(self):
+        x = tf.compat.v1.placeholder(tf.float32, [1, 56, 56, 16], name="input")
+        top_relu = tf.nn.relu(x)
+        paddings = tf.constant([[0, 0], [1, 1], [1, 1], [0, 0]])
+        x_pad = tf.pad(top_relu, paddings, "CONSTANT")
+        conv_weights = tf.compat.v1.get_variable("weight", [3, 3, 16, 16],
+                                                 initializer=tf.compat.v1.random_normal_initializer())
+        conv = tf.nn.depthwise_conv2d(x_pad, conv_weights, strides=[1, 1, 1, 1], padding="VALID")
+
+        normed = tf.compat.v1.layers.batch_normalization(conv, name='op_to_store')
+        out_name = normed.name.split(':')[0]
+
+        with tf.compat.v1.Session() as sess:
+            sess.run(tf.compat.v1.global_variables_initializer())
+            output_graph_def = graph_util.convert_variables_to_constants(
+                sess=sess,
+                input_graph_def=sess.graph_def,
+                output_node_names=[out_name])
+
+            from neural_compressor.experimental import Quantization, common
+            quantizer = Quantization('fake_yaml.yaml')
+            dataset = quantizer.dataset('dummy', shape=(100, 56, 56, 16), label=True)
+            quantizer.eval_dataloader = common.DataLoader(dataset)
+            quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = output_graph_def
+            output_graph = quantizer()
+            found_conv_fusion = False
+
+            for i in output_graph.graph_def.node:
+                if i.op == 'QuantizedDepthwiseConv2DWithBias':
+                    found_conv_fusion = True
+                    break
+
+            self.assertEqual(found_conv_fusion, True)
+
+    @disable_random()
+    def test_depthwiseconv_biasadd_fusion_with_negative_input(self):
+        x = tf.compat.v1.placeholder(tf.float32, [1, 56, 56, 16], name="input")
+        paddings = tf.constant([[0, 0], [1, 1], [1, 1], [0, 0]])
+        x_pad = tf.pad(x, paddings, "CONSTANT")
+        conv_weights = tf.compat.v1.get_variable("weight", [3, 3, 16, 16],
+                                                 initializer=tf.compat.v1.random_normal_initializer())
+        conv = tf.nn.depthwise_conv2d(x_pad, conv_weights, strides=[1, 1, 1, 1], padding="VALID")
+
+        normed = tf.compat.v1.layers.batch_normalization(conv, name='op_to_store')
+        out_name = normed.name.split(':')[0]
+
+        with tf.compat.v1.Session() as sess:
+            sess.run(tf.compat.v1.global_variables_initializer())
+            output_graph_def = graph_util.convert_variables_to_constants(
+                sess=sess,
+                input_graph_def=sess.graph_def,
+                output_node_names=[out_name])
+
+            from neural_compressor.experimental import Quantization, common
+            quantizer = Quantization('fake_yaml.yaml')
+            dataset = quantizer.dataset('dummy', shape=(100, 56, 56, 16), label=True)
+            quantizer.eval_dataloader = common.DataLoader(dataset)
+            quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = output_graph_def
+            output_graph = quantizer()
+            found_conv_fusion = False
+
+            for i in output_graph.graph_def.node:
+                if i.op == 'QuantizedDepthwiseConv2DWithBias':
+                    found_conv_fusion = True
+                    break
+
+            self.assertEqual(found_conv_fusion, False)
+
     @unittest.skipUnless(bool(
             tf.version.VERSION.find('1.15.0-up') != -1 or tf.version.VERSION >= '2.1.0'), 'not supported the current tf version.')
     @disable_random()
@@ -168,7 +239,53 @@ class TestConvBiasAddAddReluFusion(unittest.TestCase):
             self.assertEqual(found_conv_fusion, True)
 
     @disable_random()
-    def test_conv_biasadd_addv2_relu_fusion(self):
+    def test_conv_biasadd_addv2_relu_fallback_fusion(self):
+        x = tf.compat.v1.placeholder(tf.float32, [1, 56, 56, 16], name="input")
+        top_relu = tf.nn.leaky_relu(x)
+        paddings = tf.constant([[0, 0], [1, 1], [1, 1], [0, 0]])
+        x_pad = tf.pad(x, paddings, "CONSTANT")
+        conv_weights = tf.compat.v1.get_variable("weight", [3, 3, 16, 16],
+                                                 initializer=tf.compat.v1.random_normal_initializer())
+        conv = tf.nn.conv2d(x_pad, conv_weights, strides=[1, 2, 2, 1], padding="VALID")
+        normed = tf.compat.v1.layers.batch_normalization(conv)
+        # relu = tf.nn.relu(normed)
+
+        conv_weights2 = tf.compat.v1.get_variable("weight2", [3, 3, 16, 16],
+                                                  initializer=tf.compat.v1.random_normal_initializer())
+        conv2 = tf.nn.conv2d(top_relu, conv_weights2, strides=[1, 2, 2, 1], padding="SAME")
+        normed2 = tf.compat.v1.layers.batch_normalization(conv2)
+        # relu2 = tf.nn.relu(normed2)
+        add = tf.raw_ops.AddV2(x=normed, y=normed2, name='addv2')
+        relu = tf.nn.relu(add)
+        relu6 = tf.nn.relu6(relu, name='op_to_store')
+
+        out_name = relu6.name.split(':')[0]
+        with tf.compat.v1.Session() as sess:
+            sess.run(tf.compat.v1.global_variables_initializer())
+            output_graph_def = graph_util.convert_variables_to_constants(
+                sess=sess,
+                input_graph_def=sess.graph_def,
+                output_node_names=[out_name])
+
+            from neural_compressor.experimental import Quantization, common
+            quantizer = Quantization('fake_yaml.yaml')
+            dataset = quantizer.dataset('dummy', shape=(100, 56, 56, 16), label=True)
+            quantizer.eval_dataloader = common.DataLoader(dataset)
+            quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = output_graph_def
+            output_graph = quantizer()
+
+            found_conv_fusion = False
+
+            for i in output_graph.graph_def.node:
+                if i.op == 'QuantizedConv2DWithBiasAndRequantize':
+                    found_conv_fusion = True
+                    break
+
+            self.assertEqual(found_conv_fusion, True)
+
+    @disable_random()
+    def test_conv_biasadd_addv2_relu_fallback_fusion(self):
         x = tf.compat.v1.placeholder(tf.float32, [1, 56, 56, 16], name="input")
         top_relu = tf.nn.relu(x)
         paddings = tf.constant([[0, 0], [1, 1], [1, 1], [0, 0]])
